import { SafeResourceUrl } from '@angular/platform-browser';
export declare class ItemComponent {
    type: string;
    button: string;
    active: boolean;
}
export declare class TitleItemComponent extends ItemComponent {
    text: string;
    size: string;
    align: string;
    color: string;
    italic: boolean;
    bold: boolean;
    underline: boolean;
    type: string;
    constructor(text: string, size: string, align: string, color: string, italic: boolean, bold: boolean, underline: boolean);
}
export declare class VideoItemComponent extends ItemComponent {
    source: string;
    source_path: string;
    title: any;
    link: SafeResourceUrl;
    mainButton: {
        color: string;
        background: string;
        text: string;
    };
    showVideoControl: any;
    allowNext: any;
    type: string;
    media: {
        youtube: string;
        vimeo: string;
    };
    constructor(source: string, source_path: string, link: SafeResourceUrl, title: string, button: string, mainButton: any, showVideoControl: boolean, allowNext: boolean, media: {
        youtube: any;
        vimeo: any;
    });
}
export declare class TextItemComponent extends ItemComponent {
    text: string;
    textColor: string;
    textSize: number;
    textAnimation: string;
    textAlign: string;
    background: string;
    buttonBgColor: string;
    buttonTxtColor: string;
    borderWidth: string;
    borderStyle: string;
    borderRadius: string;
    type: string;
    constructor(text: string, button: string);
}
export declare class ImageItemComponent extends ItemComponent {
    url: string;
    type: string;
    title: any;
    titleSize: number;
    mainButton: {
        color: string;
        background: string;
        text: string;
    };
    constructor(url: string, button: string);
}
export declare class PdfItemComponent extends ItemComponent {
    url: string;
    title: string;
    mainButton: any;
    link: SafeResourceUrl;
    showAccept: any;
    acceptText: any;
    type: string;
    constructor(url: string, link: SafeResourceUrl, title: string, button: string);
}
export declare class ExerciseComponent extends ItemComponent {
    exercise: number;
    type: string;
    constructor(exercise: number);
}
export declare class MultiChoiceComponent extends ItemComponent {
    type: string;
    title: string;
    titleAnimation: string;
    titleSize: string;
    titleAlign: string;
    titleColor: string;
    url: string;
    feedback: string;
    feedback_text: string;
    options: Array<MultiChoiceOptions>;
    link: any;
    answersAlign: string;
    marketType: string;
    verification: string;
    color: string;
    media: string;
    mediaTitle: string;
    mediaUrl: any;
    constructor();
}
export declare class MultiChoiceOptions {
    label: string;
    correct: boolean;
    selected: boolean;
    value: string;
    messageInError: string;
    constructor();
}
export declare class PredefinedComponent extends ItemComponent {
    type: string;
    constructor();
}
export declare class ShortTextComponent extends ItemComponent {
    type: string;
    label: string;
    constructor();
}
export declare class ActionAidFormComponent extends ItemComponent {
    type: any;
    form: any;
    label: string;
    constructor();
}
export declare class IntroComponent extends ItemComponent {
    title: {
        text: string;
        align: string;
        size: number;
        color: string;
        animation: string;
    };
    media: {
        type: string;
        text: string;
        align: string;
        size: number;
        color: string;
        animation: string;
        image: string;
        youtube: string;
        vimeo: string;
        title: string;
        description: string;
    };
    link: SafeResourceUrl;
    button: string;
    buttonOptions: {
        background: string;
        color: string;
    };
    buttonColor: string;
    settings: {
        background: string;
        color: string;
        size: number;
    };
    title_animation: any;
    text_animation: any;
    layout: string;
    borderWidth: string;
    borderStyle: string;
    borderRadius: string;
    constructor();
}
export declare class ConclusionComponent extends ItemComponent {
    bg: string;
    title: {
        text: string;
        align: string;
        size?: string;
    };
    text: {
        text: string;
        align: string;
        size?: string;
    };
    button: string;
    background: string;
    textColor: string;
    featureColor: string;
    icon_animation: any;
    title_animation: any;
    text_animation: any;
    button_animation: any;
    feedback: string;
    mainButton: any;
    constructor();
}
export declare class ChallengeComponent extends ItemComponent {
    title: {
        text: string;
        align: string;
    };
    notes_title: {
        text: string;
        align: string;
    };
    notes_text: {
        text: string;
        align: string;
    };
    medias: Array<ChallengeMedia>;
    button_bg: any;
    constructor();
}
export declare class ChallengeMedia {
    type: string;
    text: {
        text: string;
        align: string;
    };
    link: SafeResourceUrl;
    url: string;
    thumb: string;
    image: string;
    video: string;
    title: string;
    description: string;
    featured: boolean;
    constructor();
}
export declare class FormComponent extends ItemComponent {
    title: string;
    lines: Array<LineForm>;
    constructor();
}
export declare class LineForm {
    title: string;
    showCols: boolean;
    cols: any;
    multiplier: string;
    extraCols: Array<Array<ColOfLineForm>>;
    constructor();
}
export declare class ColOfLineForm {
    placeholder: string;
    format: string;
    size: string;
    type: string;
    required: string;
    minLength: number;
    maxLength: number;
    selectType: string;
    multiple: string;
    constructor();
}
export declare class GroupComponent extends ItemComponent {
    title: string;
    group: GroupForm;
    constructor();
}
export declare class GroupForm {
    title: string;
    type: string;
    selectOptions: Array<any>;
    subGroups: Array<GroupForm>;
    constructor();
}
export declare class TableComponent extends ItemComponent {
    title: string;
    type: string;
    userActive: boolean;
    countLines: number;
    collumns: Array<CollumnTable>;
    media: string;
    mediaTitle: string;
    mediaUrl: string;
    constructor();
}
export declare class CollumnTable {
    type: string;
    title: string;
    align: string;
    placeholder: string;
    selectOptions: Array<any>;
    constructor();
}
export declare class MultipleQuestionComponent extends ItemComponent {
    questions: Array<MultipleQuestion>;
    constructor();
}
export declare class MultipleQuestion {
    title: string;
    options: Array<MultipleQuestionOption>;
    constructor();
}
export declare class MultipleQuestionOption {
    image: string;
    text: string;
    correct: boolean;
    constructor();
}
export declare class CorrectIncorrectComponent extends ItemComponent {
    title: {
        text: string;
        align: string;
    };
    lines: Array<CorrectIncorrectComponentLines>;
    feedback: string;
    feedbackMessage: string;
    constructor();
}
export declare class CorrectIncorrectComponentLines {
    title: string;
    feedback: string;
    correct: boolean;
    constructor();
}
export declare class UploadComponent extends ItemComponent {
    title: {
        text: string;
        align: string;
        color: string;
    };
    titleAnimation: string;
    titleSize: number;
    text: {
        text: string;
        align: string;
        color: string;
    };
    textAnimation: string;
    textSize: number;
    background: string;
    mainButton: {
        text: string;
        color: string;
        background: string;
        required: string;
    };
    file: any;
    button_bg: any;
    constructor();
}
export declare class StarPointComponent extends ItemComponent {
    title: {
        text: string;
        align: string;
        size: string;
        animation: string;
        color: string;
    };
    text: {
        text: string;
        align: string;
        size: string;
        animation: string;
        color: string;
    };
    mainButton: {
        color: string;
        background: string;
        text: string;
    };
    background: string;
    points: number;
    constructor();
}
export declare class DownloadComponent extends ItemComponent {
    layout: string;
    title: {
        text: string;
        align: string;
        size?: string;
        animation: string;
        color: string;
    };
    text: {
        text: string;
        align: string;
        size?: string;
        animation: string;
        color: string;
    };
    background: string;
    file: string;
    icon: string;
    iconColor: string;
    iconSize: number;
    downloadButton: {
        color: string;
        background: string;
        text: string;
    };
    mainButton: {
        color: string;
        background: string;
        text: string;
    };
    constructor();
}
export declare class RatingComponent extends ItemComponent {
    title: {
        text: string;
        align: string;
        size?: string;
        animation: string;
    };
    mainButton: {
        color: string;
        background: string;
        text: string;
    };
    positive: string;
    negative: string;
    titleColor: string;
    background: string;
    constructor();
}
